<?
/*****************************************************************************************
  Fileame: config.inc.php

  Purpose: Contains all settings for site

  Created: 12-27-01
  Updated: 06-24-2006
              Reorganized and split out certain config options

******************************************************************************************/

//set error reporting to not show notices
error_reporting(E_ALL ^ E_NOTICE);

if(!function_exists("loadAlternateConfig")) {
    function loadAlternateConfig($configFile, $alternate = array('local', 'vendor')) {
	for ($i = 0; $i < count($alternate); $i++) {
	    $configPath = dirname(__FILE__) . "/" . $alternate[$i] . "/" . $configFile;
	    if ( file_exists($configPath) )
		require_once($configPath);
	}
    }
}

loadAlternateConfig("config.php");

/********************************************
  DO NOT EDIT THE SETTINGS IN THIS FILE (config/config.php)!
  Add your own local settings to config/local/config.php in stead,
  otherwise you might loose your configuration when upgrading.
********************************************/


/********************************************
	Required Settings
********************************************/

//connection settings
define("DBHOST","127.0.0.1");
define("DBUSER","postgres");
define("DBPASSWORD","secret");
define("DBPORT","5432");
define("DBNAME","docmgr");

//administrator email (also return address for outgoing emails
define("ADMIN_EMAIL","admin@mydomain.com");

//site url for emailing links to files in event and task notifications
//also, this must be set appropriately for fckeditor to work.  If a client
//uses a url different from this one, fckeditor will not load.  This
//must have a trailing slash!!!
define("SITE_URL","http://docmgr.mydomain.com/");
define("SITE_PATH","/www/docmgr");

//absolute path to the docmgr files directory (no trailing slash)
define("FILE_DIR",SITE_PATH."/files");

//paths to other storage directories.  You probably don't need to change
define("TMP_DIR",FILE_DIR."/tmp");
define("DATA_DIR",FILE_DIR."/data");
define("THUMB_DIR",FILE_DIR."/thumbnails");
define("PREVIEW_DIR",FILE_DIR."/preview");
define("DOC_DIR",FILE_DIR."/document");
define("HOME_DIR",FILE_DIR."/home");

//path to shared import directory
define("IMPORT_DIR",FILE_DIR."/import");

//use ldap for accounts.  If set, alter ldap settings in ldap-config.php
//define("USE_LDAP","1");

/******************************************************************
	Indexing Options
******************************************************************/

//do not index more than this many words. 
//define("INDEX_WORD_LIMIT","1000");

//regular expression used by preg_replace when stripping content
//from imported files.  whatever you put here is what those functions
//will keep.  This is case INSENSITVE  
//	Examples:
//	a-z -> keep all letters
//	0-9 -> keep all letters and numbers
define("REGEXP_OPTION","-a-z0-9_");

/*****************************************************************
        Optional Permissions Settings
*****************************************************************/

//allow automated logins with cookies
define("USE_COOKIES","1");

//allow removal of past file revisions (yes or no)
define("FILE_REVISION_REMOVE","yes");

//allow removal of past document revisions (yes or no)
define("DOC_REVISION_REMOVE","yes");

/*****************************************************************
	Optional Settings
*****************************************************************/

//set the default language for users (not used at this moment)
define("DEFAULT_LANG","English");

//default search results per page;
define("RESULTS_PER_PAGE","10");

//number of pages of results to show at once
define("PAGE_RESULT_LIMIT","20");

//default search results per page;
//define("PAGE_BROWSE_RESULTS","1");

//max number of seconds per page per file
define("EXECUTION_TIME","60");

//date format for entering and viewing (either mm/dd/yyyy or dd/mm/yyyy);
define("DATE_FORMAT","mm/dd/yyyy");

//default view for browsing categories.  Can be either "list" or "thumb"
define("DEFAULT_BROWSE_VIEW","list");

//number of file histories to keep, 0 for unlimited
define("FILE_REVISION_LIMIT","0");

//number of document histories to keep, 0 for unlimited
define("DOC_REVISION_LIMIT","0");

//send a md5 checksum file with all email attachments
//define("SEND_MD5_CHECKSUM","1");

//if a file fails md5check when viewing, this allows the user
//to view the file anyways (after a warning is displayed)
//define("BYPASS_MD5CHECK","1");

//default docmgr path for CMS.  To enable the Intranet module,
//go to docmgr/modules/center/intranet and rename Module.xml to module.xml
//the log out and log back in
define("DEFAULT_INTRANET","/cms");

//when an object is created, this is the permissions given to non-owners
//of the object by default.  can be "view","edit", or "manage"
define("CREATE_MASK","view");

//by default, make user's home folders viewable only by them. 
//comment out to make them subject to CREATE_MASK setting
define("PRIVATE_HOME","1");

//use a trash can instead of direct delete
define("USE_TRASH","1");

/*******************************************************************
  Things you probably don't need to change
*******************************************************************/

//docmgr keepalive check (five minutes)
define("DOCMGR_KEEPALIVE","50000");

//url to the docmgr api
define("DOCMGR_API","api.php");

//what do you want the default page in docmgr to be
//your options are "docmgr" for the file browser or
//"home" for the dashboard
define("DEFAULT_MOD","home");

//tsearch2 profile to use for indexing (ignore if not using tsearch2)
//if you are indexing a non-english language, use "simple", or
//you can setup a language-specific profile through tsearch2 and
//specify it here.  The "simple" profile will not try do dictionary
//compares or determine roots of words.  If you're unsure, you
//can safely leave this unchanged
define("TSEARCH2_PROFILE","english");

//set this if nobody can delete objects except adminstrators
//define("RESTRICTED_DELETE","1");

//site theme
define("SITE_THEME","default");

define("LOGGER_MODE","db");

//name for the top level bookmark
define("ROOT_NAME","Root Level");

/*************************************************************************
  charset.  these control conversion of your database to whatever
  your web browser is expecting.  You most likely don't need to
  touch these.  
*************************************************************************/
//encoding of your database.  you probably don't need to change this
//if changed, make sure you use the value iconv (http://www.php.net/iconv) 
//recognizes for your encoding, not the encoding name postgresql uses
define("DB_CHARSET","ISO-8859-1");

//charset of the xml returned from the api
define("VIEW_CHARSET","ISO-8859-1");

/*************************************************************************
        Security Options
*************************************************************************/

//login banner.  Displayed on the login page
//define("WARNING_BANNER","Message Displayed On Login");

//Enable account lockout feature - affects all users but administrators
define("ENABLE_ACCOUNT_LOCKOUT",1);

// Number of minutes to lock out the account, 0 = forever
define("ACCOUNT_LOCKOUT_TIME",5);

// Number of attempts before an account is locked
define("ACCOUNT_LOCKOUT_ATTEMPTS",5);

// Number of minutes before a session is timed out
//define("SESSION_TIMEOUT",20);

// Select whether cookies should only be sent over secure connections
//define("SECURE_COOKIES",1);

//characters we disallow in a filename.  Anything set it here
//will prevent a file from being uploaded if set
define("DISALLOW_CHARS","\"/*");

//turn on error reporting
error_reporting(E_ALL ^ E_NOTICE);
ini_set("display_error","1");

/*************************************************************************
	Do not modify anything below this line
*************************************************************************/

//used for digest authentication on webdav
define("DIGEST_REALM","SabreDAV");

//our proto transfer protocol
define("PROTO_DEFAULT","JSON");

define("DOCMGR_URL",SITE_URL);

define("_AT","at");

//length of our permissions bitmask
define("PERM_BITLEN","32");

//required system defines
define("APP_VERSION","1.0 RC10");
define("SITE_TITLE","DocMGR ".APP_VERSION);

//define but do not set edraw
define("DSOFRAMER_ENABLE","1");
//define("TEA_ENABLE","1");

//do we process auths in this site
define("PROCESS_AUTH","1");

//reload modules every time for development
//define("DEV_MODE","1");

//the debug level for outputting messages (0 - 5).
//define("DEBUG","5");

//our directory levels (DO NOT CHANGE UNLESS YOU KNOW WHAT YOU ARE DOING!)
define("LEVEL1_NUM","16");
define("LEVEL2_NUM","256");

$exemptRequest = array();
$exemptRequest[] = "editorContent";
$exemptRequest[] = "editor_content";
$exemptRequest[] = "apidata";
$exemptRequest[] = "apiparm";
$exemptRequest[] = "to"; 
$exemptRequest[] = "from"; 
$exemptRequest[] = "cc";
$exemptRequest[] = "bcc";
