<?php

class CONFIG extends INSTALL_STEP
{

  function __construct() {
    $this->filename = "config.php";
    array_push($this->entries,
      "dbhost",
      "dbuser",
      "dbpassword",
      "dbport",
      "dbname",
      "admin_email",
      "site_url",
      "site_path",
      "file_dir"
    );
    array_push($this->emptyEntriesAllow,
      "dbhost",
      "dbport"
    );
  }
  
  public function display()
  {
    require_once('config/config.php');

    $conf = array();
    $conf['dbhost'] = importSessionC('dbhost');
    $conf['dbport'] = importSessionC('dbport');
    $conf['dbuser'] = importSessionC('dbuser');
    $conf['dbpassword'] = importSessionC('dbpassword');
    $conf['dbpassword2'] = importSession('dbpassword2', $dbpassword);
    $conf['dbname'] = importSessionC('dbname');
    $conf['site_url'] = 'https://'.$_SERVER['SERVER_NAME'].dirname($_SERVER['REQUEST_URI'] . ' ').'/';
    $conf['site_path'] = dirname(dirname(dirname(__FILE__)));
    $conf['file_dir'] = importSessionC('file_dir');
    $conf['admin_email'] = importSession('admin_email', empty($_SERVER['SERVER_ADMIN']) ? ADMIN_EMAIL : $_SERVER['SERVER_ADMIN']);
    $conf['useroot'] = importSession('use_root', true);
    $conf['superuser'] = importSession('superuser', 'postgres');
    $conf['superpass'] = importSession('superpass');

    $content = '<h3>Please enter the configure information below.</h3>
	<h2>Site config</h2>
	<div class="config-section">
	  <div class="config-input">' . aField($conf, 'admin_email', 'Admin email address:') . '</div>
	  <div class="config-input">' . aField($conf, 'site_url', 'Full site URL:') . '</div>
	  <p class="config-desc">
	    URL must contain trailing slash.
	  </p>
	  <div class="config-input">' . aField($conf, 'site_path', 'Full site path:') . '</div>
	  <div class="config-input">' . aField($conf, 'file_dir', 'DocMGR files directory:') . '</div>
	  <p class="config-desc">
	    This is the working directory for DocMGR and the location where files will be uploaded to etc.
	    Specify the absolute path without trailing slash.
	  </p>
	</div>


	<h2>Database config</h2>
	<div class="config-section">
	  <div class="config-input" style="clear:left">' . aField($conf, 'dbhost', 'Database host:') . '</div>
	  <p class="config-desc">
	    If connecting to local postgresql, leave blank to use unix sockets (<strong>recommended</strong>).
	  </p>
	  <div class="config-input">' . aField($conf, 'dbport', 'Database port:') . '</div>
	  <p class="config-desc">
	    Leave blank to use postgresql standard port.
	  </p>
	  <div class="config-input">' . aField($conf, 'dbname', 'Database name:') . '</div>
	  <div class="config-input">' . aField($conf, 'dbuser', 'Database user:') . '</div>
	  <div class="config-input">' . aField($conf, 'dbpassword', 'Database password:', 'password') . '</div>
	  <div class="config-input">' . aField($conf, 'dbpassword2', 'Database password confirm:', 'password') . '</div>
	  <p class="config-desc">
	    If you only have a single user account and database available,
	    enter those here. If you have database root access (see below)
	    you can specify new accounts/databases to be created. This account 
	    will not be created if it pre-exists. If this is the case, ensure that it
	    has SELECT, INSERT, UPDATE, and DELETE permissions on the DocMGR database.
	  </p>

	  <div class="config-input">
	  <div class="config-input">' . aField($conf, 'useroot', 'Use superuser account:', 'checkbox') . '</div>
	  <div class="config-input">' . aField($conf, 'superuser', 'Superuser name:') . '</div>
	  <div class="config-input">' . aField($conf, 'superpass', 'Superuser password:', 'password') . '</div>

	  <p class="config-desc">
	    If the database user specified above does not exist, or does not have access to create
	    the database (if needed) or tables within it, please check the box and provide details
	    of a superuser account, such as <strong>postgres</strong>, which does.
	  </p>
	</div>';

    return $content;
    
  }

  /******************************************************
    FUNCTION:	testConfig
    PURPOSE:	verifies the given db parameters
  ******************************************************/  
  protected function testConfig()
  {
    global $errors;

    if ($_POST["dbpassword"] != $_POST["dbpassword2"]) {
       $errors["dbpassword"] = "Passwords doesn't match";
       return false;
    }
    if(count($errors))
      return false;

    if ($_POST["useroot"])
      $DB = new POSTGRESQL($_POST["dbhost"],$_POST["superuser"],$_POST["superpass"],$_POST["dbport"],"postgres");
    else
      $DB = new POSTGRESQL($_POST["dbhost"],$_POST["dbuser"],$_POST["dbpassword"],$_POST["dbport"],$_POST["dbname"]);

    if (!$DB->getConn())
    {
      $this->throwError("There was an error with your database configuration");
      return false;
    }

    $version = $DB->version();

    $arr = explode(".",$version);
    
    if ($arr[0] < 8) $prob = 1;
    else if ($arr[0] == 8 && $arr[1] < 4) $prob = 1;
    else $prob = null;

    if ($prob)
    {
      $this->throwError("You must be using Postgresql 8.4 or later.  Halting setup.");
      return false;
    }
    
    $path = importSession('file_dir');
    if(!file_exists($path))
    {
      if(!mkdir($path, 0700, true)) {
	$errors['file_dir'] = "Unable to create $path";
	return false;
      }
    }
    //can we write to the files directory
    if (!is_writable($path))
    {
      $errors['file_dir'] = "Unable to write to $path directory.  Please make sure " .
                        "the user apache runs as has write access to this directory";
      return false;
    }
  
  }

}


