<?php

class DATABASE
{

  private $file;
  private $errorMessage;
  private $schemas = array("docmgr", "public", "addressbook", "logger", "modlet", "task");
    
  /******************************************************
    FUNCTION:	getError
    PURPOSE:	returns an existing class error
  ******************************************************/  
  public function getError()
  {
    return $this->errorMessage;
  }
  
  /******************************************************
    FUNCTION:	throwError
    PURPOSE:	throws a class error
  ******************************************************/  
  public function throwError($err)
  {
    $this->errorMessage = $err;
  }
  
  /******************************************************
    FUNCTION:	display
    PURPOSE:	displays the form for entering config
              information
  ******************************************************/  
  public function display()
  {

    $content = "<h3>Database Setup</h3>
                <p>The installer will now create or update your database.</p>
		<p>If you are upgrading your DocMGR installation, please backup your database before continuing.</p>";

    return $content;  
  
  }

  /******************************************************
    FUNCTION:	process
    PURPOSE:	writes our submitted values to the
              config file and saves the file
  ******************************************************/  
  public function process()
  {

    $this->checkDB();
    
  }

  protected function checkDB()
  {
    require_once('config/config.php');

    if (importSession("useroot")) {
      $superdb = new POSTGRESQL(importSession('dbhost'),importSession('superuser'),importSession('superpass'),importSession('dbport'),'postgres');
      $superdb->initial_setup(importSession('dbname'),importSession('dbuser'),importSession('dbpassword'),$this->schemas,importSession('superuser'),importSession('superpass'),'postgres');
    }

    $DB = new POSTGRESQL(importSession('dbhost'),importSession('dbuser'),importSession('dbpassword'),importSession('dbport'),importSession('dbname'));
    $superdb->initial_setup(importSession('dbname'),importSession('dbuser'),importSession('dbpassword'),$this->schemas);
    
    //see if the database already exists
    $sql = "SELECT tablename FROM pg_tables WHERE tablename NOT LIKE 'pg%'
                                            AND	tablename NOT LIKE 'sql%'";
    $info = $DB->fetch($sql);
    
    if ($info["count"] > 0)
    {

      //get our current version
      include("config/db_version.php");
      
      $arr = explode(".",DB_VERSION);

      $dbVersion = 0;

      //keep going until all upgrades are done      
      while ($dbVersion < DB_VERSION)
      {
      
        //get the database's version
        $sql = "SELECT * FROM db_version";
        $ver = $DB->single($sql);
      
        $dbVersion = $ver["version"];

        //stop here.  mission accomplished
        if ($dbVersion==DB_VERSION) break;

        //upgrade if they don't match
        if ($dbVersion > DB_VERSION)
        {

          $this->throwError("You appear to be running a later database version than this installation contains.  Abandoning setup");
          return false;      
      
        }
        else if ($dbVersion < DB_VERSION)
        {
      
          $this->upgradeDB($DB,$dbVersion);
        
        }
     
      //end while loop 
      }
    
    }
    //create from scratch
    else
    {
      $this->createDB($DB);
    }
  
    return true;
      
  }

  protected function createDB($DB)
  {
    //create the database from scratch
    $DB->setup_database(DBUSER, $this->schemas);

  }

  protected function upgradeDB($DB,$version)
  {
	
    if (!$version || $version<2010041401) $this->upgradeRC10($DB);

  }

  //upgrades from RC9 to RC10
  protected function upgradeRC10($DB)
  {

    //recreate the db_version table and put in the current database version
    $sql = "
            DROP TABLE db_version;
            CREATE TABLE db_version (
              version integer NOT NULL
            );
            INSERT INTO db_version (version) VALUES ('2010041401');
            ";
    $DB->query($sql);

    //see if they've setup dashboard for the everyone group
    $sql = "SELECT group_id FROM group_dashboard WHERE group_id='0'";
    $info = $DB->single($sql);

    //nope.  make our own    
    if (!$info)
    {
    
      $sql = "INSERT INTO group_dashboard VALUES ('0','1','1','home','bkmodlet','bkmodlet1');
            INSERT INTO group_dashboard VALUES ('0','1','2','home','taskmodlet','taskmodlet3');
            INSERT INTO group_dashboard VALUES ('0','2','1','home','currentsubscribe','currentsubscribe2');
            INSERT INTO group_dashboard VALUES ('0','2','2','home','subscribealert','subscribealert4');
            ";

            
      $DB->query($sql);
    
    }
    
  }

}
