

/****************************************************************
	FILE:			pager.js
	PURPOSE:	contains functions for displaying and manipulating
						browse/search results pager
****************************************************************/
var maxpagenum;
var minpagerange;
var maxpagerange;

/********************************************************
	FUNCTION:	createPager
	PURPOSE:	creates a pager to page through our message
						list results
********************************************************/
function createPager() {

	//setup all our images for later
	var active_first = ce("img");
	active_first.setAttribute("src","themes/" + site_theme + "/images/active_firstpage.gif");
	setClick(active_first,"firstPage()");

	var active_prev = ce("img");
	active_prev.setAttribute("src","themes/" + site_theme + "/images/active_prevpage.gif");
	setClick(active_prev,"prevPage()");

	var active_next = ce("img");
	active_next.setAttribute("src","themes/" + site_theme + "/images/active_nextpage.gif");
	setClick(active_next,"nextPage()");

	var active_last = ce("img");
	active_last.setAttribute("src","themes/" + site_theme + "/images/active_lastpage.gif");
	setClick(active_last,"lastPage()");

	//inactive images
	var inactive_first = ce("img");
	inactive_first.setAttribute("src","themes/" + site_theme + "/images/inactive_firstpage.gif");
	var inactive_prev = ce("img");
	inactive_prev.setAttribute("src","themes/" + site_theme + "/images/inactive_prevpage.gif");
	var inactive_next = ce("img");
	inactive_next.setAttribute("src","themes/" + site_theme + "/images/inactive_nextpage.gif");
	var inactive_last = ce("img");
	inactive_last.setAttribute("src","themes/" + site_theme + "/images/inactive_lastpage.gif");

	//div for storage
	var mydiv = ge("browsePager");
	var lc = ce("div","leftColumn");
	var rc = ce("div","rightColumn","searchPagerText");

	clearElement(mydiv);

	mydiv.appendChild(lc);
	mydiv.appendChild(rc);

	//save search button
	var cell = siteToolbarCell("Save Search","saveSearch()","save.png");
	cell.id = "saveSearchCell";
	rc.appendChild(cell);

	//if there are results
	if (searchTotal > 0) {

		//create our <num> out of <total> string
		var txt = ce("span");
		var max;
		var min;

		//set our min/max display for the user
		if (searchOffset==0) min = 1;
		else min = searchOffset;

		if (currentTotal < searchLimit) max = parseInt(currentTotal) + parseInt(searchOffset);
		else max = parseInt(searchLimit) + parseInt(searchOffset);
		rc.appendChild(ctnode("Viewing Results " + min + "-" + max + " of " + searchTotal));

		//numbers
		var pagenum = searchTotal / searchLimit;
		if (pagenum != parseInt(pagenum)) pagenum++;			//increment if we have a remainder
		maxpagenum = parseInt(pagenum);

		//min range is always half the result limit minus current page
		if (maxpagenum > PAGE_RESULT_LIMIT) {

			var half = parseInt(PAGE_RESULT_LIMIT/2);

			if ( (searchPage-half) <=1) {

				var minrange = 1;
				var maxrange = PAGE_RESULT_LIMIT;

			} else if (searchPage==maxpagenum) {

				var minrange = parseInt(maxpagenum) - parseInt(PAGE_RESULT_LIMIT);
				var maxrange = maxpagenum;

			} else {
				var minrange = parseInt(searchPage) - parseInt(half);
				var maxrange = parseInt(searchPage) + parseInt(half);				
			}

		} else {

			var minrange = 1;
			var maxrange = maxpagenum;

		}

		//displayed page range.  Figure out what range we are operating in
		//if pages * per/page > limit, we need an offset
		if (searchPage > PAGE_RESULT_LIMIT) {

			

		}

		for (var i=minrange;i<=maxrange;i++) {

			var link = ce("a");
			link.setAttribute("href","javascript:setPage('" + i + "')");
			link.appendChild(ctnode(i));

			if (i==searchPage) setClass(link,"curSearchPage");

			txt.appendChild(link);
		}

		//on the first page
		if (searchOffset==0 && searchTotal > searchLimit) {
			lc.appendChild(inactive_first);
			lc.appendChild(inactive_prev);
			lc.appendChild(txt);
			lc.appendChild(active_next);
			lc.appendChild(active_last);			
		}
		//on the last page
		else if (searchOffset>0 && searchOffset>=(searchTotal-currentTotal)) {
			lc.appendChild(active_first);
			lc.appendChild(active_prev);
			lc.appendChild(txt);
			lc.appendChild(inactive_next);
			lc.appendChild(inactive_last);			
		}
		else if (searchOffset==0 && currentTotal < searchLimit) {
			lc.appendChild(inactive_first);
			lc.appendChild(inactive_prev);
			lc.appendChild(txt);
			lc.appendChild(inactive_next);
			lc.appendChild(inactive_last);			
		}
		else {
			lc.appendChild(active_first);
			lc.appendChild(active_prev);
			lc.appendChild(txt);
			lc.appendChild(active_next);
			lc.appendChild(active_last);			
		}

	}

}

//for changing pages
/********************************************************
	FUNCTION:	nextPage
	PURPOSE:	cycles to the next page of msg list results
********************************************************/
function nextPage() {
	searchOffset = searchOffset + searchLimit;
	searchPage++;
	objectSearch(1);
}

/********************************************************
	FUNCTION:	prevPage
	PURPOSE:	cycles to the previous page of msg list results
********************************************************/
function prevPage() {
	searchOffset = searchOffset - searchLimit;
	searchPage--;
	objectSearch(1);
}

/********************************************************
	FUNCTION:	firstPage
	PURPOSE:	change to the first page of results
********************************************************/
function firstPage() {
	searchOffset = 0;
	searchPage = 1;
	objectSearch(1);
}

/********************************************************
	FUNCTION:	lastPage
	PURPOSE:	change to the last page of results
********************************************************/
function lastPage() {

	//calculate our final offset
	var rem = searchTotal % searchLimit;

	searchPage = maxpagenum;

	if (rem==0) searchOffset = searchTotal - searchLimit;
	else searchOffset = searchTotal - rem;

	objectSearch(1);
		
}

/********************************************************
	FUNCTION:	setPage
	PURPOSE:	change to the last page of results
********************************************************/
function setPage(num) {

	searchPage = num;
	searchOffset = searchLimit * num - searchLimit;

	objectSearch(1);
		
}

/********************************************************
	FUNCTION:	moveMessage
	PURPOSE:	moves a message to the destination folder
********************************************************/
function moveMessage(event) {

	if (!ContainerId) return false;

	var url = "index.php?module=msglist&action=movemsg&dest=" + ContainerId + "&uid=" + curuid.join(",");
	protoReq(url,"writeMoveMsg");

	//reset the container id
	ContainerId = "";

}

/********************************************************
	FUNCTION:	writeMoveMsg
	PURPOSE:	handler for moveMessage, updates our 
						listmoves a message to the destination folder
********************************************************/
function writeMoveMsg(data) {

	 
	if (data.error) alert(data.error);
	else {

		while (1) {

			var end = 0;

			//remove the message we just moved from our list
			var tbl = ge("messageListTable").getElementsByTagName("tbody")[0];
			var arr = tbl.getElementsByTagName("tr");

			for (var i=0;i<arr.length;i++) {

				var uid = arr[i].getAttribute("uid");
				var key = arraySearch(uid,curuid);
	
				//find a match, remove it and start over
				if (key!=-1) {
					tbl.removeChild(arr[i]);
					break;
				}

				if (i==(arr.length-1)) end = 1;

			}

			if (end==1 || arr.length==0) break;

		}

		//reset curuid
		curuid = new Array();

		//update our mbox
		updateMsglist();

		//if we have another message to view, show it
		if (data.nextuid) showMsg(data.nextuid);

	}

}


/*********************************************************
	functions for updating currently displayed information
*********************************************************/

/********************************************************
	FUNCTION:	updateMsglist
	PURPOSE:	this is called if a message is deleted
						or moved, or when we check for new messages.
						this updates the list w/o refreshing
						all messages in the pane
********************************************************/
function updateMsglist() {

	//if not in main view, get out (like when new messages are checked)
	if (template!="main") {
		clearSiteStatus();
		return false;
	}

	updateSiteStatus("Updating Message List");

	//assemble the url
	var url = assembleMsgUrl();
	protoReq(url,"updateMsglistInfo");

}


/********************************************************
	FUNCTION:	updateMsglistInfo
	PURPOSE:	handler for updateMsgList.  does the
						work for figuring out where new messages go,
						if there are any
	INPUT:		resp -> xml from the listmsgs module
********************************************************/
function updateMsglistInfo(data) {

	if (template!="main") {
		clearSiteStatus();
		return false;
	}

	 
	var mydiv = ge("messageListTable").getElementsByTagName("tbody")[0];

	//update the pager
	searchTotal = data.total_count;
	currentTotal = data.current_count;
	createPager();

	if (!data.msg) {

		var row = ce("tr");
		var cell = ce("td");
		setClass(cell,"errorMessage");
		cell.appendChild(ctnode("No messages available"));
		row.appendChild(cell);
		clearElement(mydiv);
		mydiv.appendChild(row);

	} else {

		//get all rows in the table body
		var arr = mydiv.getElementsByTagName("tr");

		//loop through all our messages and see if they are already in the list
		for (var i=0;i<data.msg.length;i++) {

			var curmsg = data.msg[i];
			var exists = -1;

			for (var c=0;c<arr.length;c++) {
	
				//if we have a match, then stop here because there is no need to update
				if (arr[c].getAttribute("uid")==curmsg.uid) {
					exists = c;
					break;
				}

			}

			//if it doesn't exist, we need to add it into the message list
			if (exists==-1) {

				//what's the key of the row this will go after?
				var insertKey = returnInsertKey(arr,curmsg);

				if (insertKey!=-1) {
					//If the row doesn't exist, put it at the end of the table
					if (arr[insertKey]) mydiv.insertBefore(createMsgEntry(data.msg[i]),arr[insertKey]);
					else mydiv.appendChild(createMsgEntry(data.msg[i]));
				} else mydiv.appendChild(createMsgEntry(data.msg[i]));

			}

		}

	}

	clearSiteStatus();

}

/********************************************************
	FUNCTION:	returnInsertKey
	PURPOSE:	returns the row key where our message
						needs to be inserted on the message pane
	INPUT:		arr -> array of rows currently in the table
					  curmsg -> msg data for the message we want
						to insert
********************************************************/
function returnInsertKey(arr,curmsg) {
	
	var insertKey = -1;
	var checkval;
	var checkkey;

	if (sortField=="date") {
		checkval = curmsg.date;
		checkkey = "attr";
	} else if (sortField=="size") {
		checkval = curmsg.size;
		checkkey = "attr";
	} else if (sortField=="from") {
		checkval = curmsg.from;
		checkkey = 0;
	} else if (sortField=="subject") {
		checkval = curmsg.subject;
		checkkey = 1;
	}

	for (var c=0;c<arr.length;c++) {

		if (checkkey=="attr") var rowval = arr[c].getAttribute(sortField);
		else var rowval = arr[c].getElementsByTagName("td")[checkkey].innerHTML;

		if (c==0) {

			if ( (sortDir=="asc" && checkval <= rowval) || (sortDir=="desc" && checkval >= rowval) ) {
					insertKey = 0;
					break;
				}
			
		} else if (c==(arr.length-1)) {
			if ( (sortDir=="asc" && checkval >= rowval) || (sortDir=="desc" && checkval <= rowval) ) {
				insertKey = c + 1;
				break; 
			}
		} else {

			var minval = arr[c-1].getElementsByTagName("td")[checkkey];
			var maxval = arr[c+1].getElementsByTagName("td")[checkkey];
	
			if (sortDir=="asc" && checkval >= minval && checkval <= maxval) {
				insertKey = c;
				break;
			} else if (sortDir=="desc" && checkval <= minval && checkval >= maxval) {
				break;
			}

		}

	}

	return insertKey;

}

function selectAll(mode) {

	//get all rows
	var rows = ge("messageListTable").getElementsByTagName("tr");

	//fool it into thinking ctrl key is set, because setMsg expects this
	ctrlpressed = 1;

	//figure out how many are selected
	var check = 0;
	if (mode=="unread") {
		for (var i=0;i<rows.length;i++) {
			if (rows[i].getAttribute("seen")==0) check++;
		}
	} else check = rows.length;

	var uidlen = curuid.length;

	//reset curuid
	curuid = new Array();

	//if the number of rows equals the number in curuid, then everything is already selected.
	//switch to deselect mode
	if (check==uidlen) setMsgClass();		//since we made curuid empty, this will just deselect our rows
	else {	

		for (var i=0;i<rows.length;i++) {

			var uid = rows[i].getAttribute("uid");
			var del = rows[i].getAttribute("deleted");
			var read = rows[i].getAttribute("seen");

			//if nto deleted, select it
			if (del == "0") {

					//select unread only
					if (mode=="unread") {
						if (read=="0") setMsg(uid);
					} else setMsg(uid);

			}
		}	

	}

	//unset ctrl
	ctrlpressed = 0;

}


