<?php

/**
 * This is an authentication backend that uses a file to manage passwords.
 *
 * The backend file must conform to Apache's htdigest format
 * 
 * @package Sabre
 * @subpackage DAV
 * @version $Id: File.php 866 2010-02-05 09:55:25Z evertpot@gmail.com $
 * @copyright Copyright (C) 2007-2010 Rooftop Solutions. All rights reserved.
 * @author Evert Pot (http://www.rooftopsolutions.nl/) 
 * @license http://code.google.com/p/sabredav/wiki/License Modified BSD License
 */
class Sabre_DAV_Auth_Backend_DOCMGR extends Sabre_DAV_Auth_Backend_AbstractDigest {

    /**
     * List of users 
     * 
     * @var array
     */
    protected $users = array();

    /**
     * Returns a users' information
     * 
     * @param string $realm 
     * @param string $username 
     * @return string 
     */
    public function getUserInfo($realm,$username) {

      $a = new ACCOUNT();
      $matches = $a->search(array("login"=>$username));

      if (count($matches) > 0)
      {

        $username = $matches[0]["login"];
        $password = $matches[0]["password"];      

        //if the digest_hash is stored in the db, use it.  otherwise create
        if ($matches[0]["digest_hash"]) $dg = $matches[0]["digest_hash"];
        else $dg = md5($username.":".$realm.":".$password);

        $ret = array(	"userId"=>$username,
                       "digestHash"=>$dg,
                       "password"=>$password
                       );

        return $ret;
              
      }
      else return false;

    }

    public function getUsers()
    {
    
      $a = new ACCOUNT();
      $matches = $a->search(array("login"=>$username),"login");

      $ret = array();
      $num = count($matches);
      
      for ($i=0;$i<$num;$i++) $ret[] = array("userId"=>$matches[$i]["login"]);
    
      return $ret;
      
    }


    /**
    * Returns the A1 digest hash for a specific user. 
    * 
    * @param string $username 
    * @return string 
    */
    public function getDigestHash($username) {

        $userData = $this->getUserInfo(DIGEST_REALM, $username);

        // If this was false, the user account didn't exist
        if ($userData===false) return false;

        if (!isset($userData['userId']) || !isset($userData['digestHash'])) 
        {
            throw new Sabre_DAV_Exception('The returned array from getUserInfo must contain at least a userId and digestHash element');
        }

        //init the api
        if (class_exists("APICLIENT")) $GLOBALS["DOCMGR"] = new APICLIENT($userData["userId"],$userData["password"]);

        return $userData['digestHash'];

    }
  
}




